summaryrefslogtreecommitdiff
path: root/gdb/remote-hms.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/remote-hms.c')
-rw-r--r--gdb/remote-hms.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/remote-hms.c b/gdb/remote-hms.c
index cd7f4d39c49..ee40051fb3c 100644
--- a/gdb/remote-hms.c
+++ b/gdb/remote-hms.c
@@ -1,4 +1,4 @@
/* Remote debugging interface for Hitachi HMS Monitor Version 1.0
Copyright 1995, 1996, 1998, 1999, 2000, 2001
Free Software Foundation, Inc.
Contributed by Cygnus Support. Written by Steve Chamberlain
@@ -149,7 +149,7 @@ _initialize_remote_hms (void)
init_monitor_ops (&hms_ops);
hms_ops.to_shortname = "hms";
- hms_ops.to_longname = "Hitachi Microsystems H8/300 debug monitor";
+ hms_ops.to_longname = "Renesas Microsystems H8/300 debug monitor";
hms_ops.to_doc = "Debug via the HMS monitor.\n\
Specify the serial device it is connected to (e.g. /dev/ttya).";
hms_ops.to_open = hms_open;
@@ -1,4 +1,4 @@
-/* Remote debugging interface for Hitachi HMS Monitor Version 1.0
+/* Remote debugging interface for Renesas HMS Monitor Version 1.0
Copyright 1995, 1996, 1998, 1999, 2000, 2001
Free Software Foundation, Inc.